import { watchOnce } from '@vueuse/shared'
import type { CrmVariant } from '~/src/shared/model'

export function useProductPrice() {
  const amount = ref(0)
  const currentUnitPrice = ref(0)
  const prevUnitPrice = ref()
  const variants = ref<CrmVariant[]>([])

  const currentPriceForAll = computed(() => currentUnitPrice.value * amount.value)

  const prevUnitPriceForAll = computed(() => prevUnitPrice.value * amount.value)

  watch(amount, () => {
    updatePrices()
  })

  watchOnce(variants, () => {
    updatePrices()
  })

  function updatePrices() {
    if (!variants.value.length) {
      return
    }

    for (let i = 0; i < variants.value.length; i++) {
      const variant = variants.value[i]

      let max = Number.POSITIVE_INFINITY
      let min = 0

      variant.properties?.forEach((property) => {
        if (property.name === 'min') {
          min = Number(property.value)
        }

        if (property.name === 'max')
          max = Number(property.value)
      })

      if (amount.value >= min && amount.value <= max) {
        currentUnitPrice.value = Number(variant.price) / 100

        if (i !== 0) {
          prevUnitPrice.value = Number(variants.value[i - 1].price) / 100
        }
        else {
          prevUnitPrice.value = undefined
        }

        return
      }
    }
  }

  return {
    amount,
    currentUnitPrice,
    prevUnitPrice,
    currentPriceForAll,
    prevUnitPriceForAll,
    variants,
  }
}
